# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 01:04
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0017_regcode'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='used_at',
            field=models.DateTimeField(blank=True, null=True, verbose_name=b'\xe4\xbd\xbf\xe7\x94\xa8\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 11:25
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0021_auto_20190422_1555'),
    ]

    operations = [
        migrations.AlterField(
            model_name='regcode',
            name='used_preuser',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='bee_django_crm.PreUser', verbose_name=b'\xe8\xa2\xab\xe8\xb0\x81\xe4\xbd\xbf\xe7\x94\xa8'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-06-29 06:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0024_auto_20190601_1615'),
    ]

    operations = [
        migrations.AddField(
            model_name='contract',
            name='type',
            field=models.IntegerField(choices=[(1, b'\xe6\x99\xae\xe9\x80\x9a\xe5\x90\x88\xe5\x90\x8c'), (2, b'\xe4\xba\xb2\xe5\xad\x90\xe5\x90\x88\xe5\x90\x8c')], default=1, verbose_name=b'\xe5\x90\x88\xe5\x90\x8c\xe7\xb1\xbb\xe5\x9e\x8b'),
        ),
    ]



# coding=utf-8
__author__ = 'zhangyue'
import os, datetime, urllib2, json
from django.core.management.base import BaseCommand, CommandError
from bee_django_crm.utils import loadJson
from bee_django_crm.models import Province, City, District


class Command(BaseCommand):
    def handle(self, *args, **options):
        def init_db():
            json_data = loadJson("city")
            citylist = json_data["citylist"]
            print(len(citylist).__str__() + "个省")
            for data in citylist:
                province = data["p"]
                p = save_province(province)
                city_list = data["c"]
                for city_data in city_list:
                    city = city_data["n"]
                    c = save_city(p, city)
                    # print(city)
                    if city_data.has_key("a"):
                        district_list = city_data["a"]
                        for district_data in district_list:
                            district = district_data["s"]
                            # print district
                            save_district(c, district)
            return

        def save_province(province):
            p = Province()
            p.name = province
            p.save()
            return p

        def save_city(p, city):
            c = City()
            c.province = p
            c.name = city
            c.save()
            return c

        def save_district(c, district):
            d = District()
            d.city = c
            d.name = district
            d.save()
            return

        p_list = Province.objects.all()
        if p_list.count() == 0:
            init_db()


# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 07:37
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0019_regcode_used_preuser'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='reg_number',
            field=models.IntegerField(null=True, unique=True),
        ),
    ]



#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
from django.conf.urls import include, url
from . import views

urlpatterns = [

    # ==Preuser==
    url(r'^test/$', views.test, name='test'),
    url(r'^migrate_to_fee/$', views.migrate_to_fee, name='migrate_to_fee'),
    url(r'^$', views.PreuserList.as_view(), name='index'),
    # url(r'^preuser/custom/reg/$', views.PreuserCustomReg.as_view(), name='preuser_custom_reg'),
    url(r'^preuser/list/$', views.PreuserList.as_view(), name='preuser_list'),

    url(r'^preuser/detail/(?P<pk>[0-9]+)$', views.PreuserDetail.as_view(), name='preuser_detail'),
    url(r'^preuser/add/$', views.PreuserCreate.as_view(), name='preuser_add'),
    url(r'^preuser/update/(?P<pk>[0-9]+)/$', views.update_preuser, name='preuser_update'),
    url(r'^preuser/delete/(?P<pk>[0-9]+)/$', views.PreuserDelete.as_view(), name='preuser_delete'),
    url(r'^preuser/reg/$', views.PreuserReg.as_view(), name='preuser_reg'),
    url(r'^preuser/reg/code', views.PreuserRegCode.as_view(), name='preuser_reg_code'),
    url(r'^preuser/reg_done/$', views.preuser_reg_done, name='preuser_reg_done'),
    url(r'^referral/preuser/list/$', views.ReferralPreuserList.as_view(), name='referral_preuser_list'), #经由自己介绍的preuser列表
    # api
    url(r'^preuser/api/get_name/$', views.get_name_with_user, name='get_name_with_user'),

    # =====reg code =====
    url(r'^regcode/check/$', views.RegCodeCheck.as_view(), name='regcode_check'),
    # ==Source==
    url(r'^source/list/$', views.SourceList.as_view(), name='source_list'),
    url(r'^source/detail/(?P<pk>[0-9]+)/$', views.SourceDetail.as_view(), name='source_detail'),
    url(r'^source/update/(?P<pk>[0-9]+)/$', views.SourceUpdate.as_view(), name='source_update'),
    # 二维码图片地址
    url(r'^qrcode/(?P<url>(.)+)$', views.qrcode_img, name='qrcode_img'),
    url(r'^source/qrcode/(?P<qrcode_type>(.)+)/(?P<source_id>[0-9]+)/(?P<landing_id>[0-9]+)/$', views.source_qrcode,
        name='source_qrcode'),

    url(r'^source/add/$', views.SourceCreate.as_view(), name='source_add'),
    # url(r'^source/update/(?P<pk>[0-9]+)/$', views.SourceUpdate.as_view(), name='source_update'),
    # url(r'^source/delete/(?P<pk>[0-9]+)/$', views.SourceDelete.as_view(), name='source_delete'),

    # 海报
    url(r'^poster/detail/(?P<pk>[0-9]+)/$', views.PosterDetail.as_view(), name='poster_detail'),
    url(r'^poster/create/(?P<source_id>[0-9]+)/$', views.PosterCreate.as_view(), name='poster_create'),
    url(r'^poster/update/(?P<pk>[0-9]+)/$', views.PosterUpdate.as_view(), name='poster_update'),
    url(r'^poster/delete/(?P<pk>[0-9]+)/$', views.PosterDelete.as_view(), name='poster_delete'),
    # 用户海报页
    url(r'^user/poster/$', views.UserPosterTemplate.as_view(), name='user_poster'),
    # 用户海报图片地址
    url(r'^user/poster/image/(?P<poster_id>[0-9]+)/(?P<user_id>[0-9]+)/$', views.user_poster_image,
        name='user_poster_image'),

    # ==Preuser Track==
    url(r'^preuser/track/add/(?P<preuser_id>[0-9]+)/$', views.PreuserTrackCreate.as_view(), name='preuser_track_add'),

    # ==Application question==
    url(r'^application/question/list$', views.ApplicationQuestionList.as_view(), name='application_question_list'),
    url(r'^application/question/detail/(?P<pk>[0-9]+)$', views.ApplicationQuestionDetail.as_view(),
        name='application_question_detail'),
    url(r'^application/question/add/$', views.ApplicationQuestionCreate.as_view(), name='application_question_add'),
    url(r'^application/question/update/(?P<pk>[0-9]+)/$', views.ApplicationQuestionUpdate.as_view(),
        name='application_question_update'),
    url(r'^application/question/delete/(?P<pk>[0-9]+)/$', views.ApplicationQuestionDelete.as_view(),
        name='application_question_delete'),

    # ==Application option==
    url(r'^application/option/add/(?P<pk>[0-9]+)$', views.ApplicationOptionCreate.as_view(),
        name='application_option_add'),

    # ==Preuser Application==
    url(r'^preuser/application/add/(?P<preuser_id>[0-9]+)/$', views.PreuserApplicationView.as_view(),
        name='preuser_application_add'),
    url(r'^preuser/application/update_preuser/(?P<pk>[0-9]+)$', views.PreuserApplicationUpdate.as_view(),
        name='preuser_application_update_preuser'),
    url(r'^preuser/application/done/$', views.preuser_application_done, name='preuser_application_done'),

    # ==Contract==
    url(r'^contract/list/$', views.ContractList.as_view(), name='contract_list'),
    url(r'^contract/detail/(?P<pk>[0-9]+)/$', views.ContractDetail.as_view(), name='contract_detail'),
    url(r'^contract/add/$', views.ContractCreate.as_view(), name='contract_add'),
    url(r'^contract/update/(?P<pk>[0-9]+)/$', views.ContractUpdate.as_view(), name='contract_update'),
    url(r'^contract/update/agreement/(?P<pk>[0-9]+)/$', views.ContractUpdateAgreement.as_view(), name='contract_update_agreement'),
    url(r'^contract/delete/(?P<pk>[0-9]+)/$', views.ContractDelete.as_view(), name='contract_delete'),

    # ==Preuser Contract==
    url(r'^preuser/contract/list/(?P<preuser_id>[0-9]+)$', views.PreuserContractList.as_view(),
        name='preuser_contract_list'),
    # 所有学生的合同列表
    # url(r'^preuser/contract/list/$', views.PreuserAllContractList.as_view(),
    #     name='preuser_all_contract_list'),
    url(r'^preuser/contract/detail/(?P<pk>[0-9]+)$', views.PreuserContractDetail.as_view(),
        name='preuser_contract_detail'),
    url(r'^preuser/contract/agreement/(?P<preuser_contract_id>[0-9]+)$', views.PreuserContractAgreement.as_view(),
        name='preuser_contract_agreement'),
    url(r'^preuser/contract/add/(?P<preuser_id>[0-9]+)$', views.PreuserContractCreate.as_view(),
        name='preuser_contract_add'),
    url(r'^preuser/contract/update/(?P<pk>[0-9]+)$', views.PreuserContractUpdate.as_view(),
        name='preuser_contract_update'),

    url(r'^preuser/contract/delete/(?P<pk>[0-9]+)/$', views.PreuserContractDelete.as_view(),
        name='preuser_contract_delete'),

    # 缴费
    url(r'^preuser/fee/list/(?P<preuser_id>[0-9]+)$', views.PreuserFeeList.as_view(),
        name='preuser_fee_list'),
    url(r'^preuser/fee/detail/(?P<pk>[0-9]+)$', views.PreuserFeeDetail.as_view(), name='preuser_fee_detail'),
    url(r'^preuser/fee/add/(?P<preuser_contract_id>[0-9]+)$', views.PreuserFeeCreate.as_view(),
        name='preuser_fee_add'),
    url(r'^preuser/fee/update/check/(?P<pk>[0-9]+)$', views.PreuserFeeUpdateCheck.as_view(),
        name='preuser_fee_update_check'),
    url(r'^preuser/fee/update/after/(?P<pk>[0-9]+)$', views.PreuserFeeUpdateAfter.as_view(),
        name='preuser_fee_update_after'),
    url(r'^preuser/fee/delete/(?P<pk>[0-9]+)/$', views.PreuserFeeDelete.as_view(),
        name='preuser_fee_delete'),

    # 课程卡用户创建
    url(r'^code/create/$', views.CodeUserCreateTemplate.as_view(), name='code_user_create'),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-11 09:18
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0025_contract_type'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='source',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_source', '\u53ef\u4ee5\u67e5\u770b\u6e20\u9053'), ('can_change_source_name', '\u53ef\u4ee5\u4fee\u6539\u6e20\u9053\u540d\u79f0')), 'verbose_name': 'crm\u6e20\u9053'},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-28 07:56
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0010_auto_20180823_1851'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='preuserfee',
            options={'ordering': ['-paid_at', '-created_at'], 'permissions': (('view_crm_preuser_fee', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'), ('can_check_crm_preuser_fee', '\u53ef\u4ee5\u5ba1\u6838\u7528\u6237\u7f34\u8d39'))},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-07-15 05:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0026_auto_20190711_1718'),
    ]

    operations = [
        migrations.AddField(
            model_name='regcode',
            name='course_days',
            field=models.IntegerField(null=True, verbose_name=b'\xe5\x8f\xaf\xe5\xad\xa6\xe4\xb9\xa0\xe8\xaf\xbe\xe7\xa8\x8b\xe5\xa4\xa9\xe6\x95\xb0'),
        ),
    ]



# -*- coding:utf-8 -*-
from django.dispatch import Signal

# 费用审核后的信号
fee_checked = Signal(providing_args=["preuser_fee","preuser","request"])
# fee_after_success = Signal(providing_args=["preuser_fee"])



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-08 11:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0002_auto_20180517_1758'),
    ]

    operations = [
        migrations.AlterField(
            model_name='preuser',
            name='mobile',
            field=models.CharField(max_length=15, verbose_name=b'\xe7\x94\xb5\xe8\xaf\x9d'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-05-17 09:58
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='applicationquestion',
            options={'ordering': ['order_by'], 'permissions': (('view_crm_application', '\u53ef\u4ee5\u67e5\u770b\u7533\u8bf7\u8868\u95ee\u9898\u5217\u8868\u9875'),), 'verbose_name': 'crm\u7533\u8bf7\u8868\u95ee\u9898'},
        ),
        migrations.AlterModelOptions(
            name='contract',
            options={'ordering': ['-id'], 'permissions': (('view_crm_contract', '\u53ef\u4ee5\u67e5\u770b\u5408\u540c'),), 'verbose_name': 'crm\u5408\u540c'},
        ),
        migrations.AlterModelOptions(
            name='preuser',
            options={'ordering': ['-created_at'], 'permissions': (('can_manage_crm', '\u53ef\u4ee5\u8fdb\u5165crm\u7ba1\u7406\u9875'), ('view_crm_preuser', '\u53ef\u4ee5\u67e5\u770bcrm\u7528\u6237'), ('view_crm_doc', '\u53ef\u4ee5\u67e5\u770b\u5e2e\u52a9\u6587\u6863')), 'verbose_name': 'crm\u9884\u5907\u7528\u6237'},
        ),
        migrations.AlterModelOptions(
            name='preusercontract',
            options={'ordering': ['-paid_at', '-created_at'], 'permissions': (('view_crm_preuser_contract', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'),), 'verbose_name': 'crm\u7528\u6237\u7f34\u8d39'},
        ),
        migrations.AlterModelOptions(
            name='source',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_source', '\u53ef\u4ee5\u67e5\u770b\u6e20\u9053'),), 'verbose_name': 'crm\u6e20\u9053'},
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-07-08 07:03
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0004_auto_20180622_1603'),
    ]

    operations = [
        migrations.AlterField(
            model_name='poster',
            name='photo',
            field=models.ImageField(null=True, upload_to=b'bee_django_crm/poster_photo'),
        ),
    ]
